@@ -217,8 +217,8 @@ class BasicTest(Base):
 
     def test_non_python_no_tags(self):
         filename = self._add_notes_file()
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -231,8 +231,8 @@ class BasicTest(Base):
     def test_python_no_tags(self):
         self._make_python_package()
         filename = self._add_notes_file()
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -246,8 +246,8 @@ class BasicTest(Base):
         filename = self._add_notes_file()
         self.repo.add_file('not-a-release-note.txt')
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -260,8 +260,8 @@ class BasicTest(Base):
     def test_note_commit_tagged(self):
         filename = self._add_notes_file()
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -274,8 +274,8 @@ class BasicTest(Base):
     def test_tag_with_v_prefix(self):
         filename = self._add_notes_file()
         self.repo.git('tag', '-s', '-m', 'tag with v prefix', 'v1.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -289,8 +289,8 @@ class BasicTest(Base):
         self._make_python_package()
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
         filename = self._add_notes_file()
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -305,8 +305,8 @@ class BasicTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0rc1')
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
         filename = self._add_notes_file()
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -321,8 +321,8 @@ class BasicTest(Base):
         self.repo.add_file('ignore-1.txt')
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
         self.repo.add_file('ignore-2.txt')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -337,8 +337,8 @@ class BasicTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
         f1 = self._add_notes_file()
         f2 = self._add_notes_file()
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -353,8 +353,8 @@ class BasicTest(Base):
         f1 = self._add_notes_file(commit=False)
         f2 = self._add_notes_file()
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -370,8 +370,8 @@ class BasicTest(Base):
         f1 = self._add_notes_file()
         self.repo.git('tag', '-s', '-m', 'first tag', '2.0.0')
         f2 = self._add_notes_file()
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -391,8 +391,8 @@ class BasicTest(Base):
         f2 = f1.replace('slug1', 'slug2')
         self.repo.git('mv', f1, f2)
         self.repo.commit('rename note file')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -411,8 +411,8 @@ class BasicTest(Base):
         f2 = f1.replace('slug1', 'slug0')
         self.repo.git('mv', f1, f2)
         self.repo.commit('rename note file')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -431,8 +431,8 @@ class BasicTest(Base):
         with open(os.path.join(self.reporoot, f1), 'w') as f:
             f.write('---\npreamble: new contents for file')
         self.repo.commit('edit note file')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -451,8 +451,8 @@ class BasicTest(Base):
         f2 = f1.replace('slug1', 'slug2')
         self.repo.git('mv', f1, f2)
         self.repo.commit('rename note file')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -474,8 +474,8 @@ class BasicTest(Base):
                         'slug1-0000000000000001')
         self.repo.git('mv', f1, f2)
         self.repo.commit('rename note file')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -497,8 +497,8 @@ class BasicTest(Base):
         self.c.override(
             earliest_version='2.0.0',
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -518,8 +518,8 @@ class BasicTest(Base):
         self.repo.git('rm', f1)
         self.repo.commit('remove note file')
         self.repo.git('tag', '-s', '-m', 'first tag', '2.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -546,8 +546,8 @@ class BasicTest(Base):
                                     '--pretty=%H %d',
                                     '--name-only')
         self.addDetail('git log', text_content(log_results))
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -573,8 +573,8 @@ class BasicTest(Base):
         status_results = self.repo.git('status')
         self.addDetail('git status', text_content(status_results))
         # Now run the scanner
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         self.assertEqual(
             {'*working-copy*': [
                 (os.path.join('releasenotes', 'notes', basename),
@@ -598,8 +598,8 @@ class BasicTest(Base):
         status_results = self.repo.git('status')
         self.addDetail('git status', text_content(status_results))
         # Now run the scanner
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         # Take the staged version of the file, but associate it with
         # tagged version 1.0.0 because the file was added before that
         # version.
@@ -623,8 +623,8 @@ class BasicTest(Base):
         status_results = self.repo.git('status')
         self.addDetail('git status', text_content(status_results))
         # Now run the scanner
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         # Take the staged version of the file, but associate it with
         # tagged version 1.0.0 because the file was added before that
         # version.
@@ -647,8 +647,8 @@ class BasicTest(Base):
         self.c.override(
             earliest_version=None,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -672,8 +672,8 @@ class BasicTest(Base):
         self.c.override(
             earliest_version=None,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -698,8 +698,8 @@ class IgnoreTest(Base):
         self.c.override(
             ignore_notes=[f1],
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -717,8 +717,8 @@ class IgnoreTest(Base):
         self.c.override(
             ignore_notes=[os.path.basename(f1)],
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -736,8 +736,8 @@ class IgnoreTest(Base):
         self.c.override(
             ignore_notes=[scanner._get_unique_id(f1)],
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -758,8 +758,8 @@ class IgnoreTest(Base):
                 scanner._get_unique_id(f2),
             ],
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -775,8 +775,8 @@ class FileContentsTest(Base):
     def test_basic_file(self):
         # Prove that we can get a file we have committed.
         f1 = self._add_notes_file(contents='well-known-contents')
-        r = scanner.RenoRepo(self.reporoot)
-        contents = r.get_file_at_commit(f1, 'HEAD')
+        with scanner.RenoRepo(self.reporoot) as r:
+            contents = r.get_file_at_commit(f1, 'HEAD')
         self.assertEqual(
             b'well-known-contents',
             contents,
@@ -786,8 +786,8 @@ class FileContentsTest(Base):
         # Returns None when the file does not exist at all.
         # (we have to commit something, otherwise there is no HEAD)
         self._add_notes_file(contents='well-known-contents')
-        r = scanner.RenoRepo(self.reporoot)
-        contents = r.get_file_at_commit('no-such-dir/no-such-file', 'HEAD')
+        with scanner.RenoRepo(self.reporoot) as r:
+            contents = r.get_file_at_commit('no-such-dir/no-such-file', 'HEAD')
         self.assertEqual(
             None,
             contents,
@@ -799,8 +799,8 @@ class FileContentsTest(Base):
         with open(os.path.join(self.reporoot, f1), 'w') as f:
             f.write('new contents for file')
         self.repo.commit('edit note file')
-        r = scanner.RenoRepo(self.reporoot)
-        contents = r.get_file_at_commit(f1, 'HEAD')
+        with scanner.RenoRepo(self.reporoot) as r:
+            contents = r.get_file_at_commit(f1, 'HEAD')
         self.assertEqual(
             b'new contents for file',
             contents,
@@ -813,12 +813,11 @@ class FileContentsTest(Base):
         with open(os.path.join(self.reporoot, f1), 'w') as f:
             f.write('new contents for file')
         self.repo.commit('edit note file')
-        self.scanner = scanner.Scanner(self.c)
-        r = scanner.RenoRepo(self.reporoot)
-        head = r.head()
-        parent = r.get_parents(head)[0]
-        parent = parent.decode('ascii')
-        contents = r.get_file_at_commit(f1, parent)
+        with scanner.RenoRepo(self.reporoot) as r:
+            head = r.head()
+            parent = r.get_parents(head)[0]
+            parent = parent.decode('ascii')
+            contents = r.get_file_at_commit(f1, parent)
         self.assertEqual(
             b'initial-contents',
             contents,
@@ -830,8 +829,8 @@ class FileContentsTest(Base):
         f1 = self._add_notes_file(contents='initial-contents')
         with open(os.path.join(self.reporoot, f1), 'w') as f:
             f.write('new contents for file')
-        r = scanner.RenoRepo(self.reporoot)
-        contents = r.get_file_at_commit(f1, 'HEAD')
+        with scanner.RenoRepo(self.reporoot) as r:
+            contents = r.get_file_at_commit(f1, 'HEAD')
         self.assertEqual(
             b'initial-contents',
             contents,
@@ -843,8 +842,8 @@ class FileContentsTest(Base):
         f1 = self._add_notes_file(contents='initial-contents')
         with open(os.path.join(self.reporoot, f1), 'w') as f:
             f.write('new contents for file')
-        r = scanner.RenoRepo(self.reporoot)
-        contents = r.get_file_at_commit(f1, None)
+        with scanner.RenoRepo(self.reporoot) as r:
+            contents = r.get_file_at_commit(f1, None)
         self.assertEqual(
             'new contents for file',
             contents,
@@ -858,8 +857,8 @@ class PreReleaseTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0.0a1')
         f1 = self._add_notes_file('slug1')
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0.0a2')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -875,8 +874,8 @@ class PreReleaseTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0.0b1')
         f1 = self._add_notes_file('slug1')
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0.0b2')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -892,8 +891,8 @@ class PreReleaseTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0.0rc1')
         f1 = self._add_notes_file('slug1')
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0.0rc2')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -909,8 +908,8 @@ class PreReleaseTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', 'v1.0.0.0a1')
         f1 = self._add_notes_file('slug1')
         self.repo.git('tag', '-s', '-m', 'first tag', 'v1.0.0.0a2')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -935,8 +934,8 @@ class PreReleaseTest(Base):
         self.c.override(
             collapse_pre_releases=True,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -958,8 +957,8 @@ class PreReleaseTest(Base):
         self.c.override(
             collapse_pre_releases=True,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -984,8 +983,8 @@ class PreReleaseTest(Base):
         self.c.override(
             collapse_pre_releases=True,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1015,8 +1014,8 @@ class MergeCommitTest(Base):
         time.sleep(0.1)  # force a delay between commits
         self.repo.add_file('ignore-2.txt')
         self.repo.git('tag', '-s', '-m', 'second tag', '2.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1047,8 +1046,8 @@ class MergeCommitTest(Base):
         self.repo.git('show')
         self.repo.add_file('ignore-2.txt')
         self.repo.git('tag', '-s', '-m', 'second tag', '2.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1081,8 +1080,8 @@ class MergeCommitTest(Base):
         self.repo.add_file('ignore-2.txt')
         self.repo.git('tag', '-s', '-m', 'third tag', '2.0.0')
         self.repo.add_file('ignore-3.txt')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1119,8 +1118,8 @@ class MergeCommitTest(Base):
         self.repo.add_file('ignore-2.txt')
         self.repo.git('tag', '-s', '-m', 'third tag', '2.0.0')
         self.repo.add_file('ignore-3.txt')
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1181,8 +1180,8 @@ class NullMergeTest(Base):
         # The scanner should skip over the null-merge and include the
         # notes that come before the version being merged in, up to
         # the base of the previous branch.
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1200,8 +1199,8 @@ class NullMergeTest(Base):
         self.c.override(
             ignore_null_merges=False,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1245,6 +1244,10 @@ class BranchBaseTest(Base):
         self.repo.git('checkout', 'master')
         self.scanner = scanner.Scanner(self.c)
 
+    def tearDown(self):
+        self.scanner.close()
+        super().tearDown()
+
     def test_current_branch_no_extra_commits(self):
         # checkout the branch and then ask for its base
         self.repo.git('checkout', 'not-master')
@@ -1317,8 +1320,8 @@ class BranchTest(Base):
         f21 = self._add_notes_file('slug21')
         log_text = self.repo.git('log', '--decorate')
         self.addDetail('git log', text_content(log_text))
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1342,8 +1345,8 @@ class BranchTest(Base):
         self.c.override(
             branch='stable/2',
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1370,8 +1373,8 @@ class BranchTest(Base):
         self.c.override(
             stop_at_branch_base=False,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1407,8 +1410,8 @@ class BranchTest(Base):
             branch='stable/4',
             collapse_pre_releases=False,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1444,8 +1447,8 @@ class BranchTest(Base):
             branch='stable/4',
             collapse_pre_releases=True,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1482,8 +1485,8 @@ class BranchTest(Base):
             branch='stable/4',
             collapse_pre_releases=True,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1516,8 +1519,8 @@ class BranchTest(Base):
         self.c.override(
             branch='stable/4',
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1550,8 +1553,8 @@ class BranchTest(Base):
         self.c.override(
             branch='stable/4',
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1582,8 +1585,8 @@ class BranchTest(Base):
         self.c.override(
             branch='stable/4',
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1599,8 +1602,8 @@ class BranchTest(Base):
         self.repo.git('checkout', '2.0.0')
         self.repo.git('checkout', '-b', 'stable/2')
         self.repo.git('checkout', 'master')
-        scanner1 = scanner.Scanner(self.c)
-        head1 = scanner1._get_ref('stable/2')
+        with scanner.Scanner(self.c) as scanner1:
+            head1 = scanner1._get_ref('stable/2')
         self.assertIsNotNone(head1)
         print('head1', head1)
         # Create a second repository by cloning the first.
@@ -1626,8 +1629,8 @@ class BranchTest(Base):
             cwd=reporoot2,
         ))
         c2 = config.Config(reporoot2)
-        scanner2 = scanner.Scanner(c2)
-        head2 = scanner2._get_ref('origin/stable/2')
+        with scanner.Scanner(c2) as scanner2:
+            head2 = scanner2._get_ref('origin/stable/2')
         self.assertIsNotNone(head2)
         self.assertEqual(head1, head2)
 
@@ -1635,8 +1638,8 @@ class BranchTest(Base):
         self.repo.git('checkout', '2.0.0')
         self.repo.git('checkout', '-b', 'stable/2')
         self.repo.git('checkout', 'master')
-        scanner1 = scanner.Scanner(self.c)
-        head1 = scanner1._get_ref('stable/2')
+        with scanner.Scanner(self.c) as scanner1:
+            head1 = scanner1._get_ref('stable/2')
         self.assertIsNotNone(head1)
         print('head1', head1)
         # Create a second repository by cloning the first.
@@ -1662,8 +1665,8 @@ class BranchTest(Base):
             cwd=reporoot2,
         ))
         c2 = config.Config(reporoot2)
-        scanner2 = scanner.Scanner(c2)
-        head2 = scanner2._get_ref('stable/2')
+        with scanner.Scanner(c2) as scanner2:
+            head2 = scanner2._get_ref('stable/2')
         self.assertIsNotNone(head2)
         self.assertEqual(head1, head2)
 
@@ -1680,8 +1683,8 @@ class BranchTest(Base):
         self.c.override(
             earliest_version=None,
         )
-        self.scanner = scanner.Scanner(self.c)
-        raw_results = self.scanner.get_notes_by_version()
+        with scanner.Scanner(self.c) as s:
+            raw_results = s.get_notes_by_version()
         results = {
             k: [f for (f, n) in v]
             for (k, v) in raw_results.items()
@@ -1720,6 +1723,10 @@ class ScanStopPointPrereleaseVersionsTest(Base):
         self.repo.git('tag', '-s', '-m', 'third tag', '2.0.0')
         self.repo.git('checkout', 'master')
 
+    def tearDown(self):
+        self.scanner.close()
+        super().tearDown()
+
     def test_beta_collapse(self):
         self.assertEqual(
             '1.0.0.0rc1',
@@ -1808,6 +1815,10 @@ class ScanStopPointRegularVersionsTest(Base):
         self.repo.git('tag', '-s', '-m', 'third tag', '2.0.2')
         self.repo.git('checkout', 'master')
 
+    def tearDown(self):
+        self.scanner.close()
+        super().tearDown()
+
     def test_invalid_earliest_version(self):
         self.assertIsNone(
             self.scanner._find_scan_stop_point(
@@ -1850,45 +1861,43 @@ class GetRefTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '1.0.0')
         self.repo.git('branch', 'stable/foo')
         self.repo.git('tag', 'bar-eol')
+        self.scanner = scanner.Scanner(self.c)
+
+    def tearDown(self):
+        self.scanner.close()
+        super().tearDown()
 
     def test_signed_tag(self):
-        self.scanner = scanner.Scanner(self.c)
         ref = self.scanner._get_ref('1.0.0')
         expected = self.scanner._repo.head()
         self.assertEqual(expected, ref)
 
     def test_unsigned_tag(self):
-        self.scanner = scanner.Scanner(self.c)
         ref = self.scanner._get_ref('bar-eol')
         expected = self.scanner._repo.head()
         self.assertEqual(expected, ref)
 
     def test_eol_tag_from_branch(self):
-        self.scanner = scanner.Scanner(self.c)
         ref = self.scanner._get_ref('stable/bar')
         expected = self.scanner._repo.head()
         self.assertEqual(expected, ref)
 
     def test_head(self):
-        self.scanner = scanner.Scanner(self.c)
         ref = self.scanner._get_ref(None)
         expected = self.scanner._repo.head()
         self.assertEqual(expected, ref)
 
     def test_stable_branch(self):
-        self.scanner = scanner.Scanner(self.c)
         ref = self.scanner._get_ref('stable/foo')
         expected = self.scanner._repo.head()
         self.assertEqual(expected, ref)
 
     def test_stable_branch_with_origin_prefix(self):
-        self.scanner = scanner.Scanner(self.c)
         ref = self.scanner._get_ref('origin/stable/foo')
         expected = self.scanner._repo.head()
         self.assertEqual(expected, ref)
 
     def test_no_such_value(self):
-        self.scanner = scanner.Scanner(self.c)
         self.assertRaises(
             ValueError,
             self.scanner._get_ref,
@@ -1909,17 +1918,17 @@ class TagsTest(Base):
         self.repo.git('tag', '-s', '-m', 'first tag', '3.0.0')
 
     def test_master(self):
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_tags_on_branch(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_tags_on_branch(None)
         self.assertEqual(
             ['3.0.0', '2.0.0', '1.0.0'],
             results,
         )
 
     def test_get_ref(self):
-        self.scanner = scanner.Scanner(self.c)
-        ref = self.scanner._get_ref('3.0.0')
-        expected = self.scanner._repo.head()
+        with scanner.Scanner(self.c) as s:
+            ref = s._get_ref('3.0.0')
+            expected = s._repo.head()
         self.assertEqual(expected, ref)
 
     def test_not_master(self):
@@ -1928,8 +1937,8 @@ class TagsTest(Base):
         self._add_notes_file('slug4')
         self.repo.git('tag', '-s', '-m', 'not on master', '2.0.1')
         self.repo.git('checkout', 'master')
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_tags_on_branch('not-master')
+        with scanner.Scanner(self.c) as s:
+            results = s._get_tags_on_branch('not-master')
         self.assertEqual(
             ['2.0.1', '2.0.0', '1.0.0'],
             results,
@@ -1938,8 +1947,8 @@ class TagsTest(Base):
     def test_unsigned(self):
         self._add_notes_file('slug4')
         self.repo.git('tag', '-m', 'first tag', '4.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_tags_on_branch(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_tags_on_branch(None)
         self.assertEqual(
             ['4.0.0', '3.0.0', '2.0.0', '1.0.0'],
             results,
@@ -1948,8 +1957,8 @@ class TagsTest(Base):
     def test_tagged_tag_annotated(self):
         time.sleep(1)
         self.repo.git('tag', '-s', '-m', 'fourth tag', '4.0.0', '3.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_tags_on_branch(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_tags_on_branch(None)
         self.assertEqual(
             ['3.0.0', '4.0.0', '2.0.0', '1.0.0'],
             results,
@@ -1958,8 +1967,8 @@ class TagsTest(Base):
     def test_tagged_tag_lightweight(self):
         time.sleep(1)
         self.repo.git('tag', '-m', 'fourth tag', '4.0.0', '3.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_tags_on_branch(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_tags_on_branch(None)
         self.assertEqual(
             ['3.0.0', '4.0.0', '2.0.0', '1.0.0'],
             results,
@@ -1979,8 +1988,8 @@ class VersionTest(Base):
         self.repo.git('tag', '-s', '-m', 'third tag', '3.0.0')
 
     def test_tagged_head(self):
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_current_version(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_current_version(None)
         self.assertEqual(
             '3.0.0',
             results,
@@ -1988,8 +1997,8 @@ class VersionTest(Base):
 
     def test_head_after_tag(self):
         self._add_notes_file('slug4')
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_current_version(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_current_version(None)
         self.assertEqual(
             '3.0.0-1',
             results,
@@ -2002,8 +2011,8 @@ class VersionTest(Base):
         # single second (certainly not a person).
         time.sleep(1)
         self.repo.git('tag', '-s', '-m', 'fourth tag', '4.0.0')
-        self.scanner = scanner.Scanner(self.c)
-        results = self.scanner._get_current_version(None)
+        with scanner.Scanner(self.c) as s:
+            results = s._get_current_version(None)
         self.assertEqual(
             '4.0.0',
             results,
@@ -2452,11 +2461,9 @@ class GetSeriesBranchesTest(Base):
         self.repo.add_file('test.txt')
 
     def test_none(self):
-        self.scanner = scanner.Scanner(self.c)
-        self.assertEqual(
-            [],
-            self.scanner.get_series_branches(),
-        )
+        with scanner.Scanner(self.c) as s:
+            branches = s.get_series_branches()
+        self.assertEqual([], branches)
 
     def test_real_branches_sorted_names(self):
         self.repo.git(
@@ -2465,21 +2472,17 @@ class GetSeriesBranchesTest(Base):
         self.repo.git(
             'checkout', '-b', 'stable/b',
         )
-        self.scanner = scanner.Scanner(self.c)
-        self.assertEqual(
-            ['stable/a', 'stable/b'],
-            self.scanner.get_series_branches(),
-        )
+        with scanner.Scanner(self.c) as s:
+            branches = s.get_series_branches()
+        self.assertEqual(['stable/a', 'stable/b'], branches)
 
     def test_eol_tag(self):
         self.repo.git(
             'tag', '-s', '-m', 'closed branch', 'a-eol',
         )
-        self.scanner = scanner.Scanner(self.c)
-        self.assertEqual(
-            ['stable/a'],
-            self.scanner.get_series_branches(),
-        )
+        with scanner.Scanner(self.c) as s:
+            branches = s.get_series_branches()
+        self.assertEqual(['stable/a'], branches)
 
     def test_mix_tag_and_branch(self):
         self.repo.git(
@@ -2488,8 +2491,6 @@ class GetSeriesBranchesTest(Base):
         self.repo.git(
             'checkout', '-b', 'stable/b',
         )
-        self.scanner = scanner.Scanner(self.c)
-        self.assertEqual(
-            ['stable/a', 'stable/b'],
-            self.scanner.get_series_branches(),
-        )
+        with scanner.Scanner(self.c) as s:
+            branches = s.get_series_branches()
+        self.assertEqual(['stable/a', 'stable/b'], branches)
